summary refs log tree commit diff
path: root/src/librustdoc/html/render.rs
diff options
context:
space:
mode:
authorbors <bors@rust-lang.org>2018-03-30 04:17:05 +0000
committerbors <bors@rust-lang.org>2018-03-30 04:17:05 +0000
commitd8a1bc73f742d5c1e747270bdc8b5a6e97ba3bb1 (patch)
tree59ac1ead4709d7b31c16dcab52e9511f905ae761 /src/librustdoc/html/render.rs
parent15e8c5d8466ae40c1ef9b2a1d96f9cd2c4dcccf0 (diff)
parent67e0c2b52939de562fb06910295a6247750c11bc (diff)
downloadrust-d8a1bc73f742d5c1e747270bdc8b5a6e97ba3bb1.tar.gz
rust-d8a1bc73f742d5c1e747270bdc8b5a6e97ba3bb1.zip
Auto merge of #49489 - kennytm:rollup, r=kennytm
Rollup of 10 pull requests

- Successful merges: #49443, #49445, #49446, #49463, #49464, #49466, #49468, #49473, #49484, #49486
- Failed merges:
Diffstat (limited to 'src/librustdoc/html/render.rs')
-rw-r--r--src/librustdoc/html/render.rs12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/librustdoc/html/render.rs b/src/librustdoc/html/render.rs
index 6c6d0bae688..ff6cc56e5b4 100644
--- a/src/librustdoc/html/render.rs
+++ b/src/librustdoc/html/render.rs
@@ -129,8 +129,8 @@ pub struct SharedContext {
     pub sort_modules_alphabetically: bool,
     /// Additional themes to be added to the generated docs.
     pub themes: Vec<PathBuf>,
     /// Suffix to be added on resource files (if suffix is "-v2" then "main.css" becomes
     /// "main-v2.css").
     pub resource_suffix: String,
 }
 
@@ -743,7 +743,7 @@ fn write_shared(cx: &Context,
     write(cx.dst.join(&format!("rustdoc{}.css", cx.shared.resource_suffix)),
           include_bytes!("static/rustdoc.css"))?;
 
     // To avoid "main.css" to be overwritten, we'll first run over the received themes and only
     // then we'll run over the "official" styles.
     let mut themes: HashSet<String> = HashSet::new();
 
@@ -761,9 +761,9 @@ fn write_shared(cx: &Context,
 
     write(cx.dst.join(&format!("brush{}.svg", cx.shared.resource_suffix)),
           include_bytes!("static/brush.svg"))?;
-    write(cx.dst.join(&format!("main{}.css", cx.shared.resource_suffix)),
-          include_bytes!("static/themes/main.css"))?;
-    themes.insert("main".to_owned());
+    write(cx.dst.join(&format!("light{}.css", cx.shared.resource_suffix)),
+          include_bytes!("static/themes/light.css"))?;
+    themes.insert("light".to_owned());
     write(cx.dst.join(&format!("dark{}.css", cx.shared.resource_suffix)),
           include_bytes!("static/themes/dark.css"))?;
     themes.insert("dark".to_owned());
@@ -129,8 +129,8 @@ pub struct SharedContext {
     /// Additional themes to be added to the generated docs.
     pub themes: Vec<PathBuf>,
-    /// Suffix to be added on resource files (if suffix is "-v2" then "main.css" becomes
-    /// "main-v2.css").
+    /// Suffix to be added on resource files (if suffix is "-v2" then "light.css" becomes
+    /// "light-v2.css").
     pub resource_suffix: String,
 }
@@ -743,7 +743,7 @@ fn write_shared(cx: &Context,
           include_bytes!("static/rustdoc.css"))?;
 
-    // To avoid "main.css" to be overwritten, we'll first run over the received themes and only
+    // To avoid "light.css" to be overwritten, we'll first run over the received themes and only
     // then we'll run over the "official" styles.
     let mut themes: HashSet<String> = HashSet::new();